@@ -60,7 +60,7 @@ void BaseJob::dataFinished()
 {
     if (d->m_reply->error() == QNetworkReply::NoError) {
         QByteArray data = d->m_reply->readAll();
-        qDebug() << data;
+        //qDebug() << data;
         parse(QString::fromUtf8(data.constData()));
         if (d->m_metadata.statusCode() == 100) {
             d->m_metadata.setError(Metadata::NoError);
@@ -74,6 +74,7 @@ void BaseJob::dataFinished()
     }
     emit finished(this);
 
+    d->m_reply->deleteLater();
     deleteLater();
 }
 
@@ -83,13 +84,18 @@ void BaseJob::start()
     QTimer::singleShot(0, this, SLOT(doWork()));
 }
 
-
 void BaseJob::doWork()
 {
     d->m_reply = executeRequest();
     connect(d->m_reply, SIGNAL(finished()), SLOT(dataFinished()));
 }
 
+void BaseJob::abort()
+{
+    if (d->m_reply) {
+        d->m_reply->abort();
+    }
+}
 
 PlatformDependent* BaseJob::internals()
 {
