@@ -83,7 +83,7 @@ class Provider::Private : public QSharedData {
         }
         QString user;
         QString pass;
-        if (m_internals->loadCredentials(m_baseUrl, user, pass)) {
+        if (m_internals->hasCredentials(m_baseUrl) && m_internals->loadCredentials(m_baseUrl, user, pass)) {
             m_credentialsUserName = user;
             m_credentialsPassword = pass;
         }
@@ -101,7 +101,7 @@ Provider::Provider()
 }
 
 Provider::Provider(const Provider& other)
-  : QObject(), d(other.d)
+  : d(other.d)
 {
 }
 
@@ -137,6 +137,20 @@ QString Provider::name() const
     return d->m_name;
 }
 
+bool Provider::hasCredentials()
+{
+    return d->m_internals->hasCredentials(d->m_baseUrl);
+}
+
+bool Provider::loadCredentials(QString& user, QString& password)
+{
+    return d->m_internals->loadCredentials(d->m_baseUrl, user, password);
+}
+
+bool Provider::saveCredentials(const QString& user, const QString& password)
+{
+    return d->m_internals->saveCredentials(d->m_baseUrl, user, password);
+}
 
 PostJob* Provider::checkLogin(const QString& user, const QString& password)
 {
@@ -565,7 +579,6 @@ ListJob<Event>* Provider::requestEvent(const QString& country, const QString& se
 
 QUrl Provider::createUrl(const QString& path)
 {
-    qDebug() << "create url" << path << " user: " << d->m_credentialsUserName;
     QUrl url(d->m_baseUrl.toString() + path);
     if (!d->m_credentialsUserName.isEmpty()) {
         url.setUserName(d->m_credentialsUserName);
@@ -576,7 +589,6 @@ QUrl Provider::createUrl(const QString& path)
 
 QNetworkRequest Provider::createRequest(const QUrl& url)
 {
-    qDebug() << "request with url: " << url.toString() << url.userName();
     QNetworkRequest request(url);
 
     if (!d->m_credentialsUserName.isEmpty()) {
@@ -625,6 +637,3 @@ ListJob<Message>* Provider::doRequestMessageList(const QUrl& url)
 {
     return new ListJob<Message>(d->m_internals, createRequest(url));
 }
-
-
-#include "provider.moc"
